pub struct Duration<Clock>where
Clock: Clock,{ /* private fields */ }Expand description
A span of time represented by a signed tick count.
A Duration is generic over a Clock, preventing arithmetic operations
between durations of different clocks at compile-time.
Implementations
Sourceimpl<Clock> Duration<Clock>where
Clock: Clock,
impl<Clock> Duration<Clock>where
Clock: Clock,
Sourcepub const fn from_secs(secs: i64) -> Duration<Clock>
pub const fn from_secs(secs: i64) -> Duration<Clock>
Creates a Duration from a number of seconds.
Sourcepub const fn from_millis(millis: i64) -> Duration<Clock>
pub const fn from_millis(millis: i64) -> Duration<Clock>
Creates a Duration from a number of milliseconds.
Sourcepub const fn from_micros(micros: i64) -> Duration<Clock>
pub const fn from_micros(micros: i64) -> Duration<Clock>
Creates a Duration from a number of microseconds.
Sourcepub const fn from_nanos(nanos: i64) -> Duration<Clock>
pub const fn from_nanos(nanos: i64) -> Duration<Clock>
Creates a Duration from a number of nanoseconds.
Sourcepub const fn checked_add(self, rhs: Duration<Clock>) -> Option<Duration<Clock>>
pub const fn checked_add(self, rhs: Duration<Clock>) -> Option<Duration<Clock>>
Adds another Duration, returning None if overflow occurred.
Sourcepub const fn checked_sub(self, rhs: Duration<Clock>) -> Option<Duration<Clock>>
pub const fn checked_sub(self, rhs: Duration<Clock>) -> Option<Duration<Clock>>
Subtracts another Duration, returning None if underflow occurred.