Instant

Struct Instant 

pub struct Instant<Clock>
where Clock: Clock,
{ /* private fields */ }
A measurement of a monotonically non-decreasing clock.

An Instant is generic over a Clock, preventing arithmetic operations between instants of different clocks at compile-time.

Implementations

Source

impl<Clock> Instant<Clock>
where Clock: Clock,

pub const MAX: Instant<Clock>

The maximum possible value for an Instant.

pub const MIN: Instant<Clock>

The minimum possible value for an Instant.

pub const fn from_ticks(ticks: u64) -> Instant<Clock>

Creates a new Instant from a raw tick count.

pub const fn ticks(&self) -> u64

Returns the raw tick count of this Instant.

pub const fn checked_add_duration( self, duration: Duration<Clock>, ) -> Option<Instant<Clock>>

Returns the Instant resulting from adding Duration, or None if overflow occurred.

pub const fn checked_sub_duration( self, duration: Duration<Clock>, ) -> Option<Instant<Clock>>

Returns the Instant resulting from subtracting Duration, or None if underflow occurred.