Struct SystemClock
pub struct SystemClock;Expand description
The clock used by the core system/RTOS
This clock is by the system for time bound operations such as thread sleeping, waiting on mutexes/semaphores, etc. The clock’s rate is system dependent.