pub struct Instant<Clock>where
Clock: Clock,{ /* private fields */ }Expand description
A measurement of a monotonically non-decreasing clock.
An Instant is generic over a Clock, preventing arithmetic operations
between instants of different clocks at compile-time.
Implementations
Sourceimpl<Clock> Instant<Clock>where
Clock: Clock,
impl<Clock> Instant<Clock>where
Clock: Clock,
Sourcepub const fn from_ticks(ticks: u64) -> Instant<Clock>
pub const fn from_ticks(ticks: u64) -> Instant<Clock>
Creates a new Instant from a raw tick count.
Sourcepub const fn checked_add_duration(
self,
duration: Duration<Clock>,
) -> Option<Instant<Clock>>
pub const fn checked_add_duration( self, duration: Duration<Clock>, ) -> Option<Instant<Clock>>
Returns the Instant resulting from adding Duration, or None if overflow occurred.
Sourcepub const fn checked_sub_duration(
self,
duration: Duration<Clock>,
) -> Option<Instant<Clock>>
pub const fn checked_sub_duration( self, duration: Duration<Clock>, ) -> Option<Instant<Clock>>
Returns the Instant resulting from subtracting Duration, or None if underflow occurred.